==> com.liferay.blogs.web-4.0.16.jar: META-INF/resources/blogs_admin/js/ElementsDefaultEventHandler.es.js <==
"use strict";

Liferay.Loader.define("blogs-web@4.0.16/blogs_admin/js/ElementsDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web/liferay/DefaultEventHandler.es', 'frontend-js-metal-web$metal-state'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = void 0;

  var _DefaultEventHandler2 = _interopRequireDefault(require("frontend-js-web/liferay/DefaultEventHandler.es"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var ElementsDefaultEventHandler =
  /*#__PURE__*/
  function (_DefaultEventHandler) {
    _inherits(ElementsDefaultEventHandler, _DefaultEventHandler);

    function ElementsDefaultEventHandler() {
      _classCallCheck(this, ElementsDefaultEventHandler);

      return _possibleConstructorReturn(this, _getPrototypeOf(ElementsDefaultEventHandler).apply(this, arguments));
    }

    _createClass(ElementsDefaultEventHandler, [{
      key: "delete",
      value: function _delete(itemData) {
        var message = Liferay.Language.get('are-you-sure-you-want-to-delete-this');

        if (this.trashEnabled) {
          message = Liferay.Language.get('are-you-sure-you-want-to-move-this-to-the-recycle-bin');
        }

        if (confirm(message)) {
          this._send(itemData.deleteURL);
        }
      }
    }, {
      key: "permissions",
      value: function permissions(itemData) {
        Liferay.Util.openWindow({
          dialog: {
            destroyOnHide: true,
            modal: true
          },
          dialogIframe: {
            bodyCssClass: 'dialog-with-footer'
          },
          title: Liferay.Language.get('permissions'),
          uri: itemData.permissionsURL
        });
      }
    }, {
      key: "publishToLive",
      value: function publishToLive(itemData) {
        if (confirm(Liferay.Language.get('are-you-sure-you-want-to-publish-to-live'))) {
          this._send(itemData.publishEntryURL);
        }
      }
    }, {
      key: "_send",
      value: function _send(url) {
        submitForm(document.hrefFm, url);
      }
    }]);

    return ElementsDefaultEventHandler;
  }(_DefaultEventHandler2.default);

  ElementsDefaultEventHandler.STATE = {
    trashEnabled: _metalState.Config.bool()
  };
  var _default = ElementsDefaultEventHandler;
  exports.default = _default;
  //# sourceMappingURL=ElementsDefaultEventHandler.es.js.map
});
//# sourceMappingURL=ElementsDefaultEventHandler.es.js.map

==> com.liferay.blogs.web-4.0.96.jar: META-INF/resources/blogs_admin/js/ElementsDefaultEventHandler.es.js <==
Liferay.Loader.define("blogs-web@4.0.96/blogs_admin/js/ElementsDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web', 'frontend-js-metal-web$metal-state'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _frontendJsWeb = require("frontend-js-web");

  var _metalState = require("frontend-js-metal-web$metal-state");

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var ElementsDefaultEventHandler = /*#__PURE__*/function (_DefaultEventHandler) {
    _inherits(ElementsDefaultEventHandler, _DefaultEventHandler);

    function ElementsDefaultEventHandler() {
      _classCallCheck(this, ElementsDefaultEventHandler);

      return _possibleConstructorReturn(this, _getPrototypeOf(ElementsDefaultEventHandler).apply(this, arguments));
    }

    _createClass(ElementsDefaultEventHandler, [{
      key: "delete",
      value: function _delete(itemData) {
        var message = Liferay.Language.get('are-you-sure-you-want-to-delete-this');

        if (this.trashEnabled || confirm(message)) {
          this._send(itemData.deleteURL);
        }
      }
    }, {
      key: "permissions",
      value: function permissions(itemData) {
        Liferay.Util.openWindow({
          dialog: {
            destroyOnHide: true,
            modal: true
          },
          dialogIframe: {
            bodyCssClass: 'dialog-with-footer'
          },
          title: Liferay.Language.get('permissions'),
          uri: itemData.permissionsURL
        });
      }
    }, {
      key: "publishToLive",
      value: function publishToLive(itemData) {
        if (confirm(Liferay.Language.get('are-you-sure-you-want-to-publish-to-live'))) {
          this._send(itemData.publishEntryURL);
        }
      }
    }, {
      key: "_send",
      value: function _send(url) {
        submitForm(document.hrefFm, url);
      }
    }]);

    return ElementsDefaultEventHandler;
  }(_frontendJsWeb.DefaultEventHandler);

  ElementsDefaultEventHandler.STATE = {
    trashEnabled: _metalState.Config.bool()
  };
  var _default = ElementsDefaultEventHandler;
  exports["default"] = _default;
  //# sourceMappingURL=ElementsDefaultEventHandler.es.js.map
});
//# sourceMappingURL=ElementsDefaultEventHandler.es.js.map
